@@ -377,24 +377,24 @@ class TestViews(UnicoreTestCase):
     def test_image_url(self):
         self.views = CmsViews(testing.DummyRequest({}))
 
-        self.assertEqual(
-            self.views.get_image_url('sample-uuid-000000-0001'),
+        self.assertEqual(self.views.get_image_url(
+            'sample-uuid-000000-0001', 'http://some.site.com'),
             'http://some.site.com/'
             '1bzRPrcuQPXBECF9mHxFVr11viY=/sample-uuid-000000-0001')
 
-        self.assertEqual(
-            self.views.get_image_url('sample-uuid-000000-0001', 300, 200),
+        self.assertEqual(self.views.get_image_url(
+            'sample-uuid-000000-0001', 'http://some.site.com', 300, 200),
             'http://some.site.com/'
             '8Ko7ZiKCwOv8zDovqScWL5Lgrc8=/300x200/sample-uuid-000000-0001')
 
-        self.assertEqual(
-            self.views.get_image_url('sample-uuid-000000-0001', 300),
+        self.assertEqual(self.views.get_image_url(
+            'sample-uuid-000000-0001', 'http://some.site.com', 300),
             'http://some.site.com/'
             'LUyVe1umwB1caELC5m3LWu1HxvI=/300x0/sample-uuid-000000-0001')
 
-        self.assertEqual(
-            self.views.get_image_url('sample-uuid-000000-0001', height=150),
+        self.assertEqual(self.views.get_image_url(
+            'sample-uuid-000000-0001', 'http://some.site.com', height=150),
             'http://some.site.com/'
             '4kS9gT_mYqVhnheDCuQhsahI_dU=/0x150/sample-uuid-000000-0001')
 
-        self.assertEqual(self.views.get_image_url(''), '')
+        self.assertEqual(self.views.get_image_url('', ''), '')
